==> financial-settlement-domain-0.0.358-sources.jar: com/xforceplus/financialsettlement/entity/ChargeCodeBudget.java <==
package com.xforceplus.financialsettlement.entity;

import java.time.LocalDateTime;
import com.baomidou.mybatisplus.annotation.FieldFill;
import com.baomidou.mybatisplus.annotation.TableField;
import java.io.Serializable;
import java.time.LocalDateTime;
import java.math.BigDecimal;
import java.util.HashMap;
import java.util.Map;
import com.xforceplus.ultraman.bocp.gen.util.BocpGenUtils;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * <p>
 * 
 * </p>
 *
 * @author ultraman
 * @since 2021-12-23
 */
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
public class ChargeCodeBudget implements Serializable {

  private static final long serialVersionUID=1L;

  /**
   * chargecode编号
   */
  @TableField("ccCode")
  private String ccCode;

  /**
   * 名称
   */
  @TableField("ccName")
  private String ccName;

  /**
   * 类型
   */
  @TableField("ccType")
  private String ccType;

  /**
   * 负责人工号
   */
  @TableField("ownerCode")
  private String ownerCode;

  /**
   * 负责人名称
   */
  @TableField("ownerName")
  private String ownerName;

  /**
   * 负责人直属领导人工号
   */
  @TableField("primaryLeaderCode")
  private String primaryLeaderCode;

  /**
   * 负责人直属领导人
   */
  @TableField("primaryLeaderName")
  private String primaryLeaderName;

  /**
   * CFO工号
   */
  @TableField("cfoCode")
  private String cfoCode;

  /**
   * CFO名称
   */
  @TableField("cfoName")
  private String cfoName;

  /**
   * id
   */
  private Long id;

  /**
   * 租户ID
   */
  @TableField(fill = FieldFill.INSERT)
  private Long tenantId;

  /**
   * 租户代码
   */
  @TableField(fill = FieldFill.INSERT)
  private String tenantCode;

  /**
   * 创建时间
   */
  @TableField(fill = FieldFill.INSERT)
  @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
  private LocalDateTime createTime;

  /**
   * 修改时间
   */
  @TableField(fill = FieldFill.INSERT_UPDATE)
  @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
  private LocalDateTime updateTime;

  /**
   * 创建人ID
   */
  @TableField(fill = FieldFill.INSERT)
  private Long createUserId;

  /**
   * 修改人ID
   */
  @TableField(fill = FieldFill.INSERT_UPDATE)
  private Long updateUserId;

  /**
   * 创建人名字
   */
  @TableField(fill = FieldFill.INSERT)
  private String createUserName;

  /**
   * 修改人名字
   */
  @TableField(fill = FieldFill.INSERT_UPDATE)
  private String updateUserName;

  /**
   * 删除标记
   */
  @TableField(fill = FieldFill.INSERT)
  private String deleteFlag;

  /**
   * 类型code
   */
  @TableField("ccTypeCode")
  private String ccTypeCode;

  /**
   * 一级部门负责人
   */
  @TableField("levelOneDepartmentName")
  private String levelOneDepartmentName;

  /**
   * 一级部门负责人工号
   */
  @TableField("levelOneDepartmentCode")
  private String levelOneDepartmentCode;

  /**
   * 状态
   */
  private String status;




  public Map toOQSMap(){
      Map map = new HashMap();
      map.put("ccCode", ccCode);
      map.put("ccName", ccName);
      map.put("ccType", ccType);
      map.put("ownerCode", ownerCode);
      map.put("ownerName", ownerName);
      map.put("primaryLeaderCode", primaryLeaderCode);
      map.put("primaryLeaderName", primaryLeaderName);
      map.put("cfoCode", cfoCode);
      map.put("cfoName", cfoName);
      map.put("id", id);
      map.put("tenant_id", tenantId);
      map.put("tenant_code", tenantCode);
      map.put("create_time", BocpGenUtils.toTimestamp(createTime));
      map.put("update_time", BocpGenUtils.toTimestamp(updateTime));
      map.put("create_user_id", createUserId);
      map.put("update_user_id", updateUserId);
      map.put("create_user_name", createUserName);
      map.put("update_user_name", updateUserName);
      map.put("delete_flag", deleteFlag);
      map.put("ccTypeCode", ccTypeCode);
      map.put("levelOneDepartmentName", levelOneDepartmentName);
      map.put("levelOneDepartmentCode", levelOneDepartmentCode);
      map.put("status", status);
      return map;
  }

  public static ChargeCodeBudget fromOQSMap(Map map){
    if(map == null || map.isEmpty()) {
      return null;
    }
    ChargeCodeBudget entity = new ChargeCodeBudget();
    if(map.containsKey("ccCode")) {
      Object obj = map.get("ccCode");
      if(obj != null) {
        if(obj instanceof String){
          entity.setCcCode((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("ccName")) {
      Object obj = map.get("ccName");
      if(obj != null) {
        if(obj instanceof String){
          entity.setCcName((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("ccType")) {
      Object obj = map.get("ccType");
      if(obj != null) {
        if(obj instanceof String){
          entity.setCcType((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("ownerCode")) {
      Object obj = map.get("ownerCode");
      if(obj != null) {
        if(obj instanceof String){
          entity.setOwnerCode((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("ownerName")) {
      Object obj = map.get("ownerName");
      if(obj != null) {
        if(obj instanceof String){
          entity.setOwnerName((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("primaryLeaderCode")) {
      Object obj = map.get("primaryLeaderCode");
      if(obj != null) {
        if(obj instanceof String){
          entity.setPrimaryLeaderCode((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("primaryLeaderName")) {
      Object obj = map.get("primaryLeaderName");
      if(obj != null) {
        if(obj instanceof String){
          entity.setPrimaryLeaderName((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("cfoCode")) {
      Object obj = map.get("cfoCode");
      if(obj != null) {
        if(obj instanceof String){
          entity.setCfoCode((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("cfoName")) {
      Object obj = map.get("cfoName");
      if(obj != null) {
        if(obj instanceof String){
          entity.setCfoName((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("id")) {
      Object obj = map.get("id");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setId((Long)obj);
        } else if(obj instanceof String) {
          entity.setId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer){
          entity.setId(Long.parseLong(obj.toString()));
        }
      } else{
      }
    }
    if(map.containsKey("tenant_id")) {
      Object obj = map.get("tenant_id");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setTenantId((Long)obj);
        } else if(obj instanceof String) {
          entity.setTenantId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer){
          entity.setTenantId(Long.parseLong(obj.toString()));
        }
      } else{
      }
    }
    if(map.containsKey("tenant_code")) {
      Object obj = map.get("tenant_code");
      if(obj != null) {
        if(obj instanceof String){
          entity.setTenantCode((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("create_time")) {
      Object obj = map.get("create_time");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setCreateTime(BocpGenUtils.toLocalDateTime((Long)obj));
        } else if(obj instanceof LocalDateTime){
          entity.setCreateTime((LocalDateTime)obj);
        } else if(obj instanceof String) {
          entity.setCreateTime(BocpGenUtils.toLocalDateTime(Long.parseLong((String)obj)));
        }
      } else{
        entity.setCreateTime(null);
      }
    }
    if(map.containsKey("update_time")) {
      Object obj = map.get("update_time");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setUpdateTime(BocpGenUtils.toLocalDateTime((Long)obj));
        } else if(obj instanceof LocalDateTime){
          entity.setUpdateTime((LocalDateTime)obj);
        } else if(obj instanceof String) {
          entity.setUpdateTime(BocpGenUtils.toLocalDateTime(Long.parseLong((String)obj)));
        }
      } else{
        entity.setUpdateTime(null);
      }
    }
    if(map.containsKey("create_user_id")) {
      Object obj = map.get("create_user_id");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setCreateUserId((Long)obj);
        } else if(obj instanceof String) {
          entity.setCreateUserId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer){
          entity.setCreateUserId(Long.parseLong(obj.toString()));
        }
      } else{
      }
    }
    if(map.containsKey("update_user_id")) {
      Object obj = map.get("update_user_id");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setUpdateUserId((Long)obj);
        } else if(obj instanceof String) {
          entity.setUpdateUserId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer){
          entity.setUpdateUserId(Long.parseLong(obj.toString()));
        }
      } else{
      }
    }
    if(map.containsKey("create_user_name")) {
      Object obj = map.get("create_user_name");
      if(obj != null) {
        if(obj instanceof String){
          entity.setCreateUserName((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("update_user_name")) {
      Object obj = map.get("update_user_name");
      if(obj != null) {
        if(obj instanceof String){
          entity.setUpdateUserName((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("delete_flag")) {
      Object obj = map.get("delete_flag");
      if(obj != null) {
        if(obj instanceof String){
          entity.setDeleteFlag((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("ccTypeCode")) {
      Object obj = map.get("ccTypeCode");
      if(obj != null) {
        if(obj instanceof String){
          entity.setCcTypeCode((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("levelOneDepartmentName")) {
      Object obj = map.get("levelOneDepartmentName");
      if(obj != null) {
        if(obj instanceof String){
          entity.setLevelOneDepartmentName((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("levelOneDepartmentCode")) {
      Object obj = map.get("levelOneDepartmentCode");
      if(obj != null) {
        if(obj instanceof String){
          entity.setLevelOneDepartmentCode((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("status")) {
      Object obj = map.get("status");
      if(obj != null) {
        if(obj instanceof String){
          entity.setStatus((String)obj);
        }
      } else{
      }
    }
    return entity;
  }
}

==> financial-settlement-domain-0.0.371-sources.jar: com/xforceplus/financialsettlement/entity/ChargeCodeBudget.java <==
package com.xforceplus.financialsettlement.entity;

import java.time.LocalDateTime;
import com.baomidou.mybatisplus.annotation.FieldFill;
import com.baomidou.mybatisplus.annotation.TableField;
import java.io.Serializable;
import java.time.LocalDateTime;
import java.math.BigDecimal;
import java.util.HashMap;
import java.util.Map;
import com.xforceplus.ultraman.bocp.gen.util.BocpGenUtils;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * <p>
 * 
 * </p>
 *
 * @author ultraman
 * @since 2021-12-28
 */
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
public class ChargeCodeBudget implements Serializable {

  private static final long serialVersionUID=1L;

  /**
   * chargecode编号
   */
  @TableField("ccCode")
  private String ccCode;

  /**
   * 名称
   */
  @TableField("ccName")
  private String ccName;

  /**
   * 类型
   */
  @TableField("ccType")
  private String ccType;

  /**
   * 负责人工号
   */
  @TableField("ownerCode")
  private String ownerCode;

  /**
   * 负责人名称
   */
  @TableField("ownerName")
  private String ownerName;

  /**
   * 负责人直属领导人工号
   */
  @TableField("primaryLeaderCode")
  private String primaryLeaderCode;

  /**
   * 负责人直属领导人
   */
  @TableField("primaryLeaderName")
  private String primaryLeaderName;

  /**
   * CFO工号
   */
  @TableField("cfoCode")
  private String cfoCode;

  /**
   * CFO名称
   */
  @TableField("cfoName")
  private String cfoName;

  /**
   * id
   */
  private Long id;

  /**
   * 租户ID
   */
  @TableField(fill = FieldFill.INSERT)
  private Long tenantId;

  /**
   * 租户代码
   */
  @TableField(fill = FieldFill.INSERT)
  private String tenantCode;

  /**
   * 创建时间
   */
  @TableField(fill = FieldFill.INSERT)
  @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
  private LocalDateTime createTime;

  /**
   * 修改时间
   */
  @TableField(fill = FieldFill.INSERT_UPDATE)
  @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
  private LocalDateTime updateTime;

  /**
   * 创建人ID
   */
  @TableField(fill = FieldFill.INSERT)
  private Long createUserId;

  /**
   * 修改人ID
   */
  @TableField(fill = FieldFill.INSERT_UPDATE)
  private Long updateUserId;

  /**
   * 创建人名字
   */
  @TableField(fill = FieldFill.INSERT)
  private String createUserName;

  /**
   * 修改人名字
   */
  @TableField(fill = FieldFill.INSERT_UPDATE)
  private String updateUserName;

  /**
   * 删除标记
   */
  @TableField(fill = FieldFill.INSERT)
  private String deleteFlag;

  /**
   * 类型code
   */
  @TableField("ccTypeCode")
  private String ccTypeCode;

  /**
   * 一级部门负责人
   */
  @TableField("levelOneDepartmentName")
  private String levelOneDepartmentName;

  /**
   * 一级部门负责人工号
   */
  @TableField("levelOneDepartmentCode")
  private String levelOneDepartmentCode;

  /**
   * 状态
   */
  private String status;

  /**
   * 批次号
   */
  @TableField("requestId")
  private String requestId;

  /**
   * 推送时间
   */
  @TableField("pushTime")
  private String pushTime;




  public Map toOQSMap(){
      Map map = new HashMap();
      map.put("ccCode", ccCode);
      map.put("ccName", ccName);
      map.put("ccType", ccType);
      map.put("ownerCode", ownerCode);
      map.put("ownerName", ownerName);
      map.put("primaryLeaderCode", primaryLeaderCode);
      map.put("primaryLeaderName", primaryLeaderName);
      map.put("cfoCode", cfoCode);
      map.put("cfoName", cfoName);
      map.put("id", id);
      map.put("tenant_id", tenantId);
      map.put("tenant_code", tenantCode);
      map.put("create_time", BocpGenUtils.toTimestamp(createTime));
      map.put("update_time", BocpGenUtils.toTimestamp(updateTime));
      map.put("create_user_id", createUserId);
      map.put("update_user_id", updateUserId);
      map.put("create_user_name", createUserName);
      map.put("update_user_name", updateUserName);
      map.put("delete_flag", deleteFlag);
      map.put("ccTypeCode", ccTypeCode);
      map.put("levelOneDepartmentName", levelOneDepartmentName);
      map.put("levelOneDepartmentCode", levelOneDepartmentCode);
      map.put("status", status);
      map.put("requestId", requestId);
      map.put("pushTime", pushTime);
      return map;
  }

  public static ChargeCodeBudget fromOQSMap(Map map){
    if(map == null || map.isEmpty()) {
      return null;
    }
    ChargeCodeBudget entity = new ChargeCodeBudget();
    if(map.containsKey("ccCode")) {
      Object obj = map.get("ccCode");
      if(obj != null) {
        if(obj instanceof String){
          entity.setCcCode((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("ccName")) {
      Object obj = map.get("ccName");
      if(obj != null) {
        if(obj instanceof String){
          entity.setCcName((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("ccType")) {
      Object obj = map.get("ccType");
      if(obj != null) {
        if(obj instanceof String){
          entity.setCcType((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("ownerCode")) {
      Object obj = map.get("ownerCode");
      if(obj != null) {
        if(obj instanceof String){
          entity.setOwnerCode((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("ownerName")) {
      Object obj = map.get("ownerName");
      if(obj != null) {
        if(obj instanceof String){
          entity.setOwnerName((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("primaryLeaderCode")) {
      Object obj = map.get("primaryLeaderCode");
      if(obj != null) {
        if(obj instanceof String){
          entity.setPrimaryLeaderCode((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("primaryLeaderName")) {
      Object obj = map.get("primaryLeaderName");
      if(obj != null) {
        if(obj instanceof String){
          entity.setPrimaryLeaderName((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("cfoCode")) {
      Object obj = map.get("cfoCode");
      if(obj != null) {
        if(obj instanceof String){
          entity.setCfoCode((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("cfoName")) {
      Object obj = map.get("cfoName");
      if(obj != null) {
        if(obj instanceof String){
          entity.setCfoName((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("id")) {
      Object obj = map.get("id");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setId((Long)obj);
        } else if(obj instanceof String) {
          entity.setId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer){
          entity.setId(Long.parseLong(obj.toString()));
        }
      } else{
      }
    }
    if(map.containsKey("tenant_id")) {
      Object obj = map.get("tenant_id");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setTenantId((Long)obj);
        } else if(obj instanceof String) {
          entity.setTenantId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer){
          entity.setTenantId(Long.parseLong(obj.toString()));
        }
      } else{
      }
    }
    if(map.containsKey("tenant_code")) {
      Object obj = map.get("tenant_code");
      if(obj != null) {
        if(obj instanceof String){
          entity.setTenantCode((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("create_time")) {
      Object obj = map.get("create_time");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setCreateTime(BocpGenUtils.toLocalDateTime((Long)obj));
        } else if(obj instanceof LocalDateTime){
          entity.setCreateTime((LocalDateTime)obj);
        } else if(obj instanceof String) {
          entity.setCreateTime(BocpGenUtils.toLocalDateTime(Long.parseLong((String)obj)));
        }
      } else{
        entity.setCreateTime(null);
      }
    }
    if(map.containsKey("update_time")) {
      Object obj = map.get("update_time");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setUpdateTime(BocpGenUtils.toLocalDateTime((Long)obj));
        } else if(obj instanceof LocalDateTime){
          entity.setUpdateTime((LocalDateTime)obj);
        } else if(obj instanceof String) {
          entity.setUpdateTime(BocpGenUtils.toLocalDateTime(Long.parseLong((String)obj)));
        }
      } else{
        entity.setUpdateTime(null);
      }
    }
    if(map.containsKey("create_user_id")) {
      Object obj = map.get("create_user_id");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setCreateUserId((Long)obj);
        } else if(obj instanceof String) {
          entity.setCreateUserId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer){
          entity.setCreateUserId(Long.parseLong(obj.toString()));
        }
      } else{
      }
    }
    if(map.containsKey("update_user_id")) {
      Object obj = map.get("update_user_id");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setUpdateUserId((Long)obj);
        } else if(obj instanceof String) {
          entity.setUpdateUserId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer){
          entity.setUpdateUserId(Long.parseLong(obj.toString()));
        }
      } else{
      }
    }
    if(map.containsKey("create_user_name")) {
      Object obj = map.get("create_user_name");
      if(obj != null) {
        if(obj instanceof String){
          entity.setCreateUserName((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("update_user_name")) {
      Object obj = map.get("update_user_name");
      if(obj != null) {
        if(obj instanceof String){
          entity.setUpdateUserName((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("delete_flag")) {
      Object obj = map.get("delete_flag");
      if(obj != null) {
        if(obj instanceof String){
          entity.setDeleteFlag((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("ccTypeCode")) {
      Object obj = map.get("ccTypeCode");
      if(obj != null) {
        if(obj instanceof String){
          entity.setCcTypeCode((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("levelOneDepartmentName")) {
      Object obj = map.get("levelOneDepartmentName");
      if(obj != null) {
        if(obj instanceof String){
          entity.setLevelOneDepartmentName((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("levelOneDepartmentCode")) {
      Object obj = map.get("levelOneDepartmentCode");
      if(obj != null) {
        if(obj instanceof String){
          entity.setLevelOneDepartmentCode((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("status")) {
      Object obj = map.get("status");
      if(obj != null) {
        if(obj instanceof String){
          entity.setStatus((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("requestId")) {
      Object obj = map.get("requestId");
      if(obj != null) {
        if(obj instanceof String){
          entity.setRequestId((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("pushTime")) {
      Object obj = map.get("pushTime");
      if(obj != null) {
        if(obj instanceof String){
          entity.setPushTime((String)obj);
        }
      } else{
      }
    }
    return entity;
  }
}
